@@ -17,6 +17,7 @@
 #include <QSettings>
 
 #include "scroll_management.h"
+#include "mouse_handler.h"
 
 class ComicDB;
 class Comic;
@@ -147,9 +148,6 @@ private:
     int translatorXPos;
     QPropertyAnimation *translatorAnimation;
 
-    int yDragOrigin;
-    int xDragOrigin;
-
     NotificationsLabelWidget *notificationsLabel;
 
     bool shouldOpenNext;
@@ -165,6 +163,8 @@ private:
     //! Event handlers:
     void resizeEvent(QResizeEvent *event) override;
     void wheelEvent(QWheelEvent *event) override;
+    void wheelEventMouse(QWheelEvent *event);
+    void wheelEventTrackpad(QWheelEvent *event);
     void mouseMoveEvent(QMouseEvent *event) override;
 
     int verticalScrollStep() const;
@@ -183,6 +183,9 @@ private:
     int animationDuration() const;
     void animateScroll(QPropertyAnimation &scroller, const QScrollBar &scrollBar, int delta);
 
+    //! Mouse handler
+    std::unique_ptr<YACReader::MouseHandler> mouseHandler;
+
 public:
     Viewer(QWidget *parent = nullptr);
     ~Viewer();
@@ -210,6 +213,9 @@ signals:
     void magnifyingGlassSizeDown();
     void magnifyingGlassZoomIn();
     void magnifyingGlassZoomOut();
+    void resetMagnifyingGlass();
+
+    friend class YACReader::MouseHandler;
 };
 
 #endif
