@@ -1,7 +1,9 @@
 #ifndef SELECT_COMIC_H
 #define SELECT_COMIC_H
 
-#include "scraper_selector.h"
+#include <QtWidgets>
+
+#include "scraper_results_paginator.h"
 
 class QLabel;
 class VolumeComicsModel;
@@ -10,12 +12,12 @@ class QModelIndex;
 class ScraperScrollLabel;
 class ScraperTableView;
 
-class SelectComic : public ScraperSelector
+class SelectComic : public QWidget
 {
     Q_OBJECT
 public:
     SelectComic(QWidget *parent = nullptr);
-    void load(const QString &json, const QString &searchString) override;
+    void load(const QString &json, const QString &volumeId);
     virtual ~SelectComic();
 
 public slots:
@@ -24,11 +26,20 @@ public slots:
     void setDescription(const QString &jsonDetail);
     QString getSelectedComicId();
 
+signals:
+    void loadPage(QString, int);
+
+private slots:
+    void loadNextPage();
+    void loadPreviousPage();
+
 private:
     QLabel *cover;
     ScraperScrollLabel *detailLabel;
     ScraperTableView *tableComics;
     VolumeComicsModel *model;
+    QString currentVolumeId;
+    ScraperResultsPaginator *paginator;
 };
 
 #endif // SELECT_COMIC_H
