@@ -11,6 +11,7 @@
 #include "comic_db.h"
 #include "db_helper.h"
 #include "reading_list_model.h"
+
 #ifdef use_unarr
 #include <unarr.h>
 #endif
@@ -489,11 +490,10 @@ int ComicModel::rowCount(const QModelIndex &parent) const
 QStringList ComicModel::getPaths(const QString &_source)
 {
     QStringList paths;
-    QString source = _source + "/.yacreaderlibrary/covers/";
     QList<ComicItem *>::ConstIterator itr;
     for (itr = _data.constBegin(); itr != _data.constEnd(); itr++) {
         QString hash = (*itr)->data(ComicModel::Hash).toString();
-        paths << source + hash + ".jpg";
+        paths << LibraryPaths::coverPath(_source, hash);
     }
 
     return paths;
@@ -833,12 +833,12 @@ void ComicModel::takeData(const QList<ComicItem *> &data)
 
 void ComicModel::takeUpdatedData(const QList<ComicItem *> &updatedData, std::function<bool(ComicItem *, ComicItem *)> comparator)
 {
-    int lenght = _data.size();
-    int lenghtUpdated = updatedData.size();
+    int length = _data.size();
+    int lengthUpdated = updatedData.size();
 
     int i; // index of the internal data
     int j; // index of the updated children
-    for (i = 0, j = 0; i < lenght && j < lenghtUpdated;) {
+    for (i = 0, j = 0; i < length && j < lengthUpdated;) {
         auto comic = _data.at(i);
         auto updatedComic = updatedData.at(j);
 
@@ -869,7 +869,7 @@ void ComicModel::takeUpdatedData(const QList<ComicItem *> &updatedData, std::fun
 
             i++;
             j++;
-            lenght++;
+            length++;
             continue;
         }
 
@@ -881,13 +881,13 @@ void ComicModel::takeUpdatedData(const QList<ComicItem *> &updatedData, std::fun
 
             endRemoveRows();
 
-            lenght--;
+            length--;
             continue;
         }
     }
 
     // add remaining comics
-    for (; j < lenghtUpdated; j++) {
+    for (; j < lengthUpdated; j++) {
         beginInsertRows(QModelIndex(), i, i);
 
         _data.append(updatedData.at(j));
@@ -897,12 +897,12 @@ void ComicModel::takeUpdatedData(const QList<ComicItem *> &updatedData, std::fun
         i++;
     }
 
-    // remove remaining comics {
-    for (; i < lenght; i++) {
-        beginRemoveRows(QModelIndex(), i, i);
+    // remove remaining comics
+    for (int k = length - 1; k >= i; k--) {
+        beginRemoveRows(QModelIndex(), k, k);
 
-        delete _data.at(i);
-        _data.removeAt(i);
+        delete _data.at(k);
+        _data.removeAt(k);
 
         endRemoveRows();
     }
@@ -1228,10 +1228,10 @@ void ComicModel::notifyCoverChange(const ComicDB &comic)
     // this doesn't work in QML -> emit dataChanged(index(itemIndex, 0), index(itemIndex, 0), QVector<int>() << CoverPathRole);
 }
 
-// ????
 QUrl ComicModel::getCoverUrlPathForComicHash(const QString &hash) const
 {
-    return QUrl::fromLocalFile(_databasePath + "/covers/" + hash + ".jpg");
+    auto coverPath = LibraryPaths::coverPathFromLibraryDataPath(_databasePath, hash);
+    return QUrl::fromLocalFile(coverPath);
 }
 
 void ComicModel::addComicsToFavorites(const QList<qulonglong> &comicIds)
