@@ -29,6 +29,27 @@ private:
     void run() override;
 };
 
+struct DatabaseAccess {
+    bool libraryExists;
+    bool canRead; // db read
+    bool canWrite; // db write
+    bool canWriteToFolder; // disk write
+
+    operator QString() const
+    {
+        if (libraryExists && canRead && canWrite && canWriteToFolder) {
+            return "OK";
+        } else if (!libraryExists) {
+            return "WARNING! Library does not exist on disk";
+        } else {
+            return QString("WARNING! DB read access: %1, DB write access: %2, can write to disk: %3")
+                    .arg(canRead ? "YES" : "NO")
+                    .arg(canWrite ? "YES" : "NO")
+                    .arg(canWriteToFolder ? "YES" : "NO");
+        }
+    }
+};
+
 class DataBaseManagement : public QObject
 {
     Q_OBJECT
@@ -46,7 +67,7 @@ public:
     static QSqlDatabase createDatabase(QString name, QString path);
     static QSqlDatabase createDatabase(QString dest);
     // carga una base de datos desde la ruta path
-    static QSqlDatabase loadDatabase(QString path);
+    static QSqlDatabase loadDatabase(QString libraryDataPath);
     static QSqlDatabase loadDatabaseFromFile(QString path);
     static bool createTables(QSqlDatabase &database);
     static bool createComicInfoTable(QSqlDatabase &database, QString tableName);
@@ -57,7 +78,9 @@ public:
 
     static QString checkValidDB(const QString &fullPath); // retorna "" si la DB es inválida ó la versión si es válida.
     static int compareVersions(const QString &v1, const QString v2); // retorna <0 si v1 < v2, 0 si v1 = v2 y >0 si v1 > v2
-    static bool updateToCurrentVersion(const QString &path);
+    static bool updateToCurrentVersion(const QString &libraryPath);
+
+    static DatabaseAccess getDatabaseAccess(const QString &libraryPath);
 };
 
 #endif
