@@ -7,19 +7,19 @@ class EmptyContainerInfo : public QWidget
 {
     Q_OBJECT
 public:
-    explicit EmptyContainerInfo(QWidget *parent = 0);
-    void setPixmap(const QPixmap & pixmap);
-    void setText(const QString & text);
+    explicit EmptyContainerInfo(QWidget *parent = nullptr);
+    void setPixmap(const QPixmap &pixmap);
+    void setText(const QString &text);
     QVBoxLayout *setUpDefaultLayout(bool addStretch);
 signals:
 
 public slots:
 
 protected:
-    void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *) override;
 
-    QLabel * iconLabel;
-    QLabel * titleLabel;
+    QLabel *iconLabel;
+    QLabel *titleLabel;
     QString backgroundColor;
 };
 
