@@ -4,14 +4,16 @@
 #include <QObject>
 #include <QtCore>
 
+namespace stefanfrings {
 class HttpSessionStore;
+}
 class YACReaderHttpSession;
 
 class YACReaderHttpSessionStore : public QObject
 {
     Q_OBJECT
 public:
-    explicit YACReaderHttpSessionStore(HttpSessionStore *sessionStore, QObject *parent = nullptr);
+    explicit YACReaderHttpSessionStore(stefanfrings::HttpSessionStore *sessionStore, QObject *parent = nullptr);
 
     void addYACReaderHttpSession(const QByteArray &httpSessionId, YACReaderHttpSession *yacreaderHttpSession);
     YACReaderHttpSession *getYACReaderSessionHttpSession(const QByteArray &httpSessionId);
@@ -22,7 +24,7 @@ public slots:
 
 private:
     QMap<QByteArray, YACReaderHttpSession *> sessions;
-    HttpSessionStore *sessionStore;
+    stefanfrings::HttpSessionStore *sessionStore;
     QTimer cleanupTimer;
 
     QMutex mutex;
